@@ -37,8 +37,6 @@
 #include "dbus.h"
 #include "gsupplicant.h"
 
-#define TIMEOUT 5000
-
 #define IEEE80211_CAP_ESS	0x0001
 #define IEEE80211_CAP_IBSS	0x0002
 #define IEEE80211_CAP_PRIVACY	0x0010
@@ -653,8 +651,8 @@ static void interface_capability(const char *key, DBusMessageIter *iter,
 		dbus_int32_t max_scan_ssid;
 
 		dbus_message_iter_get_basic(iter, &max_scan_ssid);
-		if (max_scan_ssid < 1)
-			max_scan_ssid = 1;
+		if (max_scan_ssid < 2)
+			max_scan_ssid = 0;
 		interface->max_scan_ssids = max_scan_ssid;
 
 	} else
@@ -2744,7 +2742,7 @@ static void add_scan_frequencies(DBusMessageIter *iter,
 	unsigned int freq;
 	int i;
 
-	for (i = 0; i < scan_data->num_ssids; i++) {
+	for (i = 0; i < scan_data->num_freqs; i++) {
 		freq = scan_data->freqs[i];
 		if (!freq)
 			break;
@@ -2886,6 +2884,9 @@ int g_supplicant_interface_scan(GSupplicantInterface *interface,
 	data->user_data = user_data;
 	data->scan_params = scan_data;
 
+        interface->scan_callback = callback;
+        interface->scan_data = user_data;
+
 	ret = supplicant_dbus_method_call(interface->path,
 			SUPPLICANT_INTERFACE ".Interface", "Scan",
 			interface_scan_params, interface_scan_result, data);
